"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandNames = exports.skipPackageManagerCheck = void 0;
exports.rcOptionsTypes = rcOptionsTypes;
exports.cliOptionsTypes = cliOptionsTypes;
exports.help = help;
exports.handler = handler;
const cli_utils_1 = require("@pnpm/cli-utils");
const error_1 = require("@pnpm/error");
const render_help_1 = __importDefault(require("render-help"));
const envRemove_1 = require("./envRemove");
const envUse_1 = require("./envUse");
const envList_1 = require("./envList");
const envAdd_1 = require("./envAdd");
exports.skipPackageManagerCheck = true;
function rcOptionsTypes() {
    return {};
}
function cliOptionsTypes() {
    return {
        global: Boolean,
        remote: Boolean,
    };
}
exports.commandNames = ['env'];
function help() {
    return (0, render_help_1.default)({
        description: 'Manage Node.js versions.',
        descriptionLists: [
            {
                title: 'Commands',
                list: [
                    {
                        description: 'Installs the specified version of Node.js. The npm CLI bundled with the given Node.js version gets installed as well. This sets this version of Node.js as the current version.',
                        name: 'use',
                    },
                    {
                        description: 'Installs the specified version(s) of Node.js without activating them as the current version.',
                        name: 'add',
                    },
                    {
                        description: 'Removes the specified version(s) of Node.js.',
                        name: 'remove',
                        shortAlias: 'rm',
                    },
                    {
                        description: 'List Node.js versions available locally or remotely',
                        name: 'list',
                        shortAlias: 'ls',
                    },
                ],
            },
            {
                title: 'Options',
                list: [
                    {
                        description: 'Manages Node.js versions globally',
                        name: '--global',
                        shortAlias: '-g',
                    },
                    {
                        description: 'List the remote versions of Node.js',
                        name: '--remote',
                    },
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('env'),
        usages: [
            'pnpm env [command] [options] <version> [<additional-versions>...]',
            'pnpm env use --global 18',
            'pnpm env use --global lts',
            'pnpm env use --global argon',
            'pnpm env use --global latest',
            'pnpm env use --global rc/18',
            'pnpm env add --global 18',
            'pnpm env add --global 18 19 20.6.0',
            'pnpm env remove --global 18 lts',
            'pnpm env remove --global argon',
            'pnpm env remove --global latest',
            'pnpm env remove --global rc/18 18 20.6.0',
            'pnpm env list',
            'pnpm env list --remote',
            'pnpm env list --remote 18',
            'pnpm env list --remote lts',
            'pnpm env list --remote argon',
            'pnpm env list --remote latest',
            'pnpm env list --remote rc/18',
        ],
    });
}
async function handler(opts, params) {
    if (params.length === 0) {
        throw new error_1.PnpmError('ENV_NO_SUBCOMMAND', 'Please specify the subcommand', {
            hint: help(),
        });
    }
    if (opts.global && !opts.bin) {
        throw new error_1.PnpmError('CANNOT_MANAGE_NODE', 'Unable to manage Node.js because pnpm was not installed using the standalone installation script', {
            hint: 'If you want to manage Node.js with pnpm, you need to remove any Node.js that was installed by other tools, then install pnpm using one of the standalone scripts that are provided on the installation page: https://pnpm.io/installation',
        });
    }
    switch (params[0]) {
        case 'add': {
            return (0, envAdd_1.envAdd)(opts, params.slice(1));
        }
        case 'use': {
            return (0, envUse_1.envUse)(opts, params.slice(1));
        }
        case 'remove':
        case 'rm':
        case 'uninstall':
        case 'un': {
            return (0, envRemove_1.envRemove)(opts, params.slice(1));
        }
        case 'list':
        case 'ls': {
            return (0, envList_1.envList)(opts, params.slice(1));
        }
        default: {
            throw new error_1.PnpmError('ENV_UNKNOWN_SUBCOMMAND', 'This subcommand is not known');
        }
    }
}
//# sourceMappingURL=env.js.map