"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.envRemove = envRemove;
/* eslint-disable no-await-in-loop */
const util_1 = __importDefault(require("util"));
const assert_1 = __importDefault(require("assert"));
const error_1 = require("@pnpm/error");
const logger_1 = require("@pnpm/logger");
const remove_bins_1 = require("@pnpm/remove-bins");
const rimraf_1 = __importDefault(require("@zkochan/rimraf"));
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const downloadNodeVersion_1 = require("./downloadNodeVersion");
const node_1 = require("./node");
const utils_1 = require("./utils");
async function envRemove(opts, params) {
    if (!opts.global) {
        throw new error_1.PnpmError('NOT_IMPLEMENTED_YET', '"pnpm env remove <version>" can only be used with the "--global" option currently');
    }
    let failed = false;
    for (const version of params) {
        const err = await removeNodeVersion(opts, version);
        if (err) {
            logger_1.logger.error(err);
            failed = true;
        }
    }
    return { exitCode: failed ? 1 : 0 };
}
async function removeNodeVersion(opts, version) {
    const { nodeVersion } = await (0, downloadNodeVersion_1.getNodeVersion)(opts, version);
    const nodeDir = (0, node_1.getNodeVersionsBaseDir)(opts.pnpmHomeDir);
    if (!nodeVersion) {
        return new error_1.PnpmError('COULD_NOT_RESOLVE_NODEJS', `Couldn't find Node.js version matching ${version}`);
    }
    const versionDir = path_1.default.resolve(nodeDir, nodeVersion);
    if (!(0, fs_1.existsSync)(versionDir)) {
        return new error_1.PnpmError('ENV_NO_NODE_DIRECTORY', `Couldn't find Node.js directory in ${versionDir}`);
    }
    const { nodePath, nodeLink } = await (0, utils_1.getNodeExecPathAndTargetDir)(opts.pnpmHomeDir);
    if (nodeLink?.includes(versionDir)) {
        (0, logger_1.globalInfo)(`Node.js ${nodeVersion} was detected as the default one, removing ...`);
        const npmPath = path_1.default.resolve(opts.pnpmHomeDir, 'npm');
        const npxPath = path_1.default.resolve(opts.pnpmHomeDir, 'npx');
        try {
            await Promise.all([
                (0, remove_bins_1.removeBin)(nodePath),
                (0, remove_bins_1.removeBin)(npmPath),
                (0, remove_bins_1.removeBin)(npxPath),
            ]);
        }
        catch (err) {
            (0, assert_1.default)(util_1.default.types.isNativeError(err));
            if (!('code' in err && err.code === 'ENOENT'))
                return err;
        }
    }
    await (0, rimraf_1.default)(versionDir);
    (0, logger_1.globalInfo)(`Node.js ${nodeVersion} was removed
${versionDir}`);
    return undefined;
}
//# sourceMappingURL=envRemove.js.map