"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.envUse = envUse;
const fs_1 = require("fs");
const util_1 = __importDefault(require("util"));
const graceful_fs_1 = __importDefault(require("graceful-fs"));
const path_1 = __importDefault(require("path"));
const error_1 = require("@pnpm/error");
const cmd_shim_1 = __importDefault(require("@zkochan/cmd-shim"));
const is_windows_1 = __importDefault(require("is-windows"));
const symlink_dir_1 = __importDefault(require("symlink-dir"));
const utils_1 = require("./utils");
const downloadNodeVersion_1 = require("./downloadNodeVersion");
async function envUse(opts, params) {
    if (!opts.global) {
        throw new error_1.PnpmError('NOT_IMPLEMENTED_YET', '"pnpm env use <version>" can only be used with the "--global" option currently');
    }
    const nodeInfo = await (0, downloadNodeVersion_1.downloadNodeVersion)(opts, params[0]);
    if (!nodeInfo) {
        throw new error_1.PnpmError('COULD_NOT_RESOLVE_NODEJS', `Couldn't find Node.js version matching ${params[0]}`);
    }
    const { nodeDir, nodeVersion } = nodeInfo;
    const src = (0, utils_1.getNodeExecPathInNodeDir)(nodeDir);
    const dest = (0, utils_1.getNodeExecPathInBinDir)(opts.bin);
    await (0, symlink_dir_1.default)(nodeDir, path_1.default.join(opts.pnpmHomeDir, utils_1.CURRENT_NODE_DIRNAME));
    try {
        graceful_fs_1.default.unlinkSync(dest);
    }
    catch (err) {
        if (!(util_1.default.types.isNativeError(err) && 'code' in err && err.code === 'ENOENT'))
            throw err;
    }
    await symlinkOrHardLink(src, dest);
    try {
        let npmDir = nodeDir;
        if (process.platform !== 'win32') {
            npmDir = path_1.default.join(npmDir, 'lib');
        }
        npmDir = path_1.default.join(npmDir, 'node_modules/npm');
        if (opts.configDir) {
            // We want the global npm settings to persist when Node.js or/and npm is changed to a different version,
            // so we tell npm to read the global config from centralized place that is outside of npm's directory.
            await fs_1.promises.writeFile(path_1.default.join(npmDir, 'npmrc'), `globalconfig=${path_1.default.join(opts.configDir, 'npmrc')}`, 'utf-8');
        }
        const npmBinDir = path_1.default.join(npmDir, 'bin');
        const cmdShimOpts = { createPwshFile: false };
        await (0, cmd_shim_1.default)(path_1.default.join(npmBinDir, 'npm-cli.js'), path_1.default.join(opts.bin, 'npm'), cmdShimOpts);
        await (0, cmd_shim_1.default)(path_1.default.join(npmBinDir, 'npx-cli.js'), path_1.default.join(opts.bin, 'npx'), cmdShimOpts);
    }
    catch {
        // ignore
    }
    return `Node.js ${nodeVersion} was activated
${dest} -> ${src}`;
}
// On Windows, symlinks only work with developer mode enabled
// or with admin permissions. So it is better to use hard links on Windows.
async function symlinkOrHardLink(existingPath, newPath) {
    if ((0, is_windows_1.default)()) {
        return fs_1.promises.link(existingPath, newPath);
    }
    return fs_1.promises.symlink(existingPath, newPath, 'file');
}
//# sourceMappingURL=envUse.js.map