"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseNodeSpecifier = parseNodeSpecifier;
const error_1 = require("@pnpm/error");
const isStableVersion = (version) => /^[0-9]+\.[0-9]+\.[0-9]+$/.test(version);
const STABLE_RELEASE_ERROR_HINT = 'The correct syntax for stable release is strictly X.Y.Z or release/X.Y.Z';
function parseNodeSpecifier(specifier) {
    if (specifier.includes('/')) {
        const [releaseChannel, useNodeVersion] = specifier.split('/');
        if (releaseChannel === 'release') {
            if (!isStableVersion(useNodeVersion)) {
                throw new error_1.PnpmError('INVALID_NODE_VERSION', `"${specifier}" is not a valid Node.js version`, {
                    hint: STABLE_RELEASE_ERROR_HINT,
                });
            }
        }
        else if (!useNodeVersion.includes(releaseChannel)) {
            throw new error_1.PnpmError('MISMATCHED_RELEASE_CHANNEL', `Node.js version (${useNodeVersion}) must contain the release channel (${releaseChannel})`);
        }
        return { releaseChannel, useNodeVersion };
    }
    const prereleaseMatch = specifier.match(/^[0-9]+\.[0-9]+\.[0-9]+-(nightly|rc|test|v8-canary)(\..+)$/);
    if (prereleaseMatch != null) {
        return { releaseChannel: prereleaseMatch[1], useNodeVersion: specifier };
    }
    if (isStableVersion(specifier)) {
        return { releaseChannel: 'release', useNodeVersion: specifier };
    }
    let hint;
    if (['nightly', 'rc', 'test', 'v8-canary'].includes(specifier)) {
        hint = `The correct syntax for ${specifier} release is strictly X.Y.Z-${specifier}.W`;
    }
    else if (/^[0-9]+\.[0-9]+$/.test(specifier) || /^[0-9]+$/.test(specifier) || ['release', 'stable', 'latest'].includes(specifier)) {
        hint = STABLE_RELEASE_ERROR_HINT;
    }
    throw new error_1.PnpmError('INVALID_NODE_VERSION', `"${specifier}" is not a valid Node.js version`, { hint });
}
//# sourceMappingURL=parseNodeSpecifier.js.map